Learn R Programming

BINCOR (version 0.2.1)

BINCOR-package: Estimate the Correlation Between Two Irregular Time Series

Description

'BINCOR' estimates the correlation between two irregular time series that are not necessarily sampled on identical time points. This program is also applicable to the situation of two evenly spaced time series that are not on the same time grid. 'BINCOR' is based on a novel estimation approach proposed by Mudelsee (2010, 2014) to estimate the correlation between two climate time series with different timescales. The idea is that autocorrelation (AR1 process) allows to correlate values obtained on different time points. The outputs (plots) can be displayed in the screen or can be saved as PNG, JPG or PDF formats. The 'BINCOR' package also provides two examples with real data: instrumental (ENSO.dat and NHSST.dat data sets) and paleoclimatic (ID31.dat and ID32.dat data sets) time series to exemplify its use. A description of the method and package is provided in Polanco-Martínez et al. (2019), <URL: tools:::Rd_expr_doi("10.32614/RJ-2019-035")>.

Arguments

Author

Josué M. Polanco-Martínez (a.k.a. jomopo).
Dept. of Statistics, Fac. of Sciences, Unversity of Salamanca, SPAIN.
Web1: https://scholar.google.es/citations?user=8djLIhcAAAAJ&hl=en.
Web2: https://www.researchgate.net/profile/Josue_Polanco-Martinez.
Email: josue.m.polanco@gmail.com

Acknowledgement:
JMPM was funded by a Basque Government post-doctoral fellowship (2016-2018).

Details

Package:BINCOR
Type:Package
Version:0.2.1
Date:2026-02-23
License:GPL (>= 2)
LazyLoad:yes

BINCOR package contains four functions: the bin_cor (the main function to build the binned time series), the plot_ts (to plot and compare the irregular and binned time series), the cor_ts (to estimate the correlation between the binned time series) and the ccf_ts (to estimate the cross-correlation between the binned time series).

References

Borchers, H. W. (2015). pracma: Practical Numerical Math Functions. R package version 1.8.8, The Comprehensive R Archive Network (CRAN), <URL: https://CRAN.R-project.org/package=pracma>.

Bunn, A., Korpela, M., Biondi, F., Campelo, F., Mérian, P., Qeadan, F., Zang, C., Buras, A., Cecile, J., Mudelsee, M., Schulz, M. (2015). Dendrochronology Program Library in R, R package version 1.6.3, The Comprehensive R Archive Network (CRAN), <URL: https://CRAN.R-project.org/package=dplR>.

Mudelsee, M. (2010). Climate Time Series Analysis: Classical Statistical and Bootstrap Methods. Springer.

Mudelsee, M. (2014). Climate Time Series Analysis: Classical Statistical and Bootstrap Methods, Second Edition. Springer.

Polanco-Martínez, J.M., Medina-Elizalde, M.A., Sánchez Goñi, M.F., M. Mudelsee. (2019). BINCOR: an R package to estimate the correlation between two unevenly spaced time series. R Journal, 11(1), 170-184, <URL: tools:::Rd_expr_doi("doi:10.32614/RJ-2019-035")>.