Learn R Programming

BINCOR (version 0.2.1)

ID31.dat: Unevenly-spaced pollen record from the marine sediments core (MD04-2845) collected on the southwestern European margin.

Description

The data set ID31.dat contains one paleoclimate (pollen percentages) time series spanning a time interval between 73,000 and 15,000 years before present (BP), thus covering the last glacial period (LGP). This data set come from a global pollen and charcoal database (Sánchez Goñi et al., 2017) developed in the framework of the INQUA International Focus Group ACER (Abrupt Climate Changes and Environmental Responses). The paleoclimate time series come from the site MD04-2845 and contains 77 elements (Sánchez Goñi et al., 2008, 2017).

Usage

data(MD04_2845_siteID31)

Arguments

Format

One file in ASCII format containing 77 elements and two variables (time and pollen percentages).