Learn R Programming

BINCOR (version 0.2.1)

ID32.dat: Unevenly-spaced pollen record from the marine sediments core (MD95-2039) collected on the southwestern European margin.

Description

The data set ID32.dat contains a paleoclimate (pollen percentages) time series spanning a time interval between 73,000 and 15,000 years before present (BP), thus covering the last glacial period (LGP). This data set come from a global pollen and charcoal database (Sánchez Goñi et al., 2017) developed in the framework of the INQUA International Focus Group ACER (Abrupt Climate Changes and Environmental Responses). The time series come from the site MD95-2039 and contains 141 elements (Roucoux et al., 2005; Sánchez Goñi et al., 2017).

Usage

data(MD95_2039_siteID32)

Arguments

Format

One file in ASCII format containing and 141 elements and two variables (time and pollen percentages).