The redfitMinls function is used by the redfitTauest
function to calculate the persistence for unevenly spaced climate time
series under study. redfitTauest is included in the
redfit function of the R dplR package (Bunn et al. 2015).
redfitMinls(t, x)
t and x are the times and the variables for an unevenly spaced time series.
Mikko Korpela.
2013-2015 Aalto University, FINLAND.
Web: https://github.com/mvkorpel.
Email: mvkorpel@iki.fi
The redfitMinls function minimize (optimize) by least
squares to obtain some parameters of the AR1 model used to estimate
the persistence through the method of Mudelsee (2002). More information
about redfitMinls function can be found in Bunn et al.
(2015) and Mudelsee (2002).
Bunn, A., Korpela, M., Biondi, F., Campelo, F., Mérian, P., Qeadan, F.,
Zang, C., Buras, A., Cecile, J., Mudelsee, M., Schulz, M. (2015).
Dendrochronology Program Library in R, R package version 1.6.3,
The Comprehensive R Archive Network (CRAN),
<URL: https://CRAN.R-project.org/package=dplR>.
Mudelsee, M. (2002). TAUEST: A computer program for estimating persistence
in unevenly spaced weather/climate time series. Computers & Geosciences,
28(1), 69--72. <URL: tools:::Rd_expr_doi("https://doi.org/10.1016/S0098-3004(01)00041-3")>.
Schulz, M., Mudelsee M. (2002). REDFIT: estimating red-noise spectra directly
from unevenly spaced paleoclimatic time series. Computers & Geosciences,
28(3), 421--426. <URL: tools:::Rd_expr_doi("10.1016/S0098-3004(01)00044-9")>.
Mudelsee, M. (2010). Climate Time Series Analysis: Classical Statistical and
Bootstrap Methods. Springer.
Mudelsee, M. (2014). Climate Time Series Analysis: Classical Statistical and
Bootstrap Methods, Second Edition. Springer.