The redfitTauest function is used by bin_cor
function to calculate the persistence for irregular climate time
series under study. redfitTauest is included in the
redfit function that come from the R dplR package
(Bunn et al. 2015).
redfitTauest(t, x)
t and x are the times and the variables for an unevenly spaced time series.
Mikko Korpela .
2013-2015 Aalto University, FINLAND.
Web: https://github.com/mvkorpel.
Email: mvkorpel@iki.fi
The redfitTauest function estimate the persistence of an
irregular times series through the method of Mudelsee (2002).
redfitTauest function is used by the dplR package
to estimate the persistence contained in irregular climate time
series. More information about redfitTauest function can
be found in Bunn et al. (2015) and Mudelsee (2002).
Bunn, A., Korpela, M., Biondi, F., Campelo, F., Mérian, P., Qeadan, F.,
Zang, C., Buras, A., Cecile, J., Mudelsee, M., Schulz, M. (2015).
Dendrochronology Program Library in R. R package version 1.6.3.
URL https://CRAN.R-project.org/package=dplR.
Mudelsee, M. (2002). TAUEST: A computer program for estimating persistence
in unevenly spaced weather/climate time series. Computers & Geosciences 28
(1), 69--72.
URL http://www.climate-risk-analysis.com/software/.
Schulz, M., Mudelsee M. (2002). REDFIT: estimating red-noise spectra directly
from unevenly spaced paleoclimatic time series. Computers & Geosciences 28(3),
421--426.
URL https://www.marum.de/Michael-Schulz/Michael-Schulz-Software.html.
Mudelsee, M. (2010). Climate Time Series Analysis: Classical Statistical and
Bootstrap Methods. Springer.
Mudelsee, M. (2014). Climate Time Series Analysis: Classical Statistical and
Bootstrap Methods, Second Edition. Springer.